@@ -83,6 +83,9 @@ class Client(object):
     def invoice_list_items(self, **kw):
         return self.call('invoice_list_items', **kw)
 
+    def invoice_clear_items(self, **kw):
+        return self.call('invoice_clear_items', **kw)
+
     def customer_add(self, **kw):
         return self.call('customer_add', **kw)
 
